##  Quick Filters
The status cards at the top of the discoveries list act as quick filters. For example, choosing the Action Needed card will remove all current filters and apply the filter to only list items requiring action. Choosing the Total card will remove all filters, and the list shows all discovered items.
